@Echo Off
REM
REM BackUpSource
REM ------------
REM Jesper Wachs, version 1, January 2020.
REM
REM Utility to extract source and data files from IBM i.
REM
REM Leave :SetupConfig here.
Call :SetupConfig
REM
REM Here you must put all the libraries that you want to extract.
REM
Call :GetSourceAndData "QGPL"
Call :GetSourceAndData "MYLIB"

REM
REM Perform cleanup and exit.
REM
Goto :Exit
REM
REM SetupConfig
REM -----------
REM Setup configuration values.
REM
:SetupConfig
set scriptfile="%~dp0%~n0.script"
set logfile="%~dp0%~n0-1.log"
set logfile2="%~dp0%~n0-2.log"

Echo.
set /p ibminame= Enter name or IP of IBM i:
Echo.
set /p user= Enter id for iSeries userprofile:
Echo.
set /p pwd= Enter password for iSeries userprofile:
Echo.

if exist %scriptfile%      del %scriptfile%
if exist %logfile%         del %logfile%
if exist %logfile2%        del %logfile2%
if exist "%~dp0%~n0-3.log" del "%~dp0%~n0-3.log"
if exist "%~dp0%~n0-4.log" del "%~dp0%~n0-4.log"
if exist "%~dp0%~n0-5.log" del "%~dp0%~n0-5.log"

Exit /b
REM
REM GetSourceAndData
REM ----------------
REM Subroutine that will initiate the retrieval of Source code and Data files.
REM
:GetSourceAndData Library
REM
REM Check that the library exists.
REM
REM
REM Connect and test if target is an IBM i.
REM
Echo.
Echo Verifying system, user id and password.
Echo.
Echo Please wait....
Echo.
Echo open %ibminame% > %scriptfile%
Echo %user% >> %scriptfile%
Echo %pwd% >> %scriptfile%
Echo quote system >> %scriptfile%
Echo Quit >> %scriptfile%
REM
REM Execute FTP
REM
FTP -s:%scriptfile% > %logfile% 2>&1
REM
REM Check that we are connected to an IBMi.
REM
FIND /V "530 " < %logfile% > %logfile2%
If errorlevel == 1 (
Echo.
Echo ====================================================================
Echo Error occured!
Echo --------------
Echo Either the user is/password is not correct or the system is not an
Echo IBM i.
Echo ====================================================================
Echo.
Echo Check the log below:
Echo ------------------------[ Start of log ]----------------------------
Type %logfile%
Echo -------------------------[ End of log ]-----------------------------
Pause
Goto Exit
)

if not exist "%~1" md "%~1"
set lib=%~1

Echo open %ibminame% > %scriptfile%
Echo %user% >> %scriptfile%
Echo %pwd% >> %scriptfile%
Echo quote rcmd chkobj %lib% *lib >> %scriptfile%
Echo Quit >> %scriptfile%
REM
REM Execute FTP
REM
FTP -s:%scriptfile% > %logfile% 2>&1
REM
REM Check that we are connected to an IBM i.
REM
FIND "550-" < %logfile% > %logfile2%
If errorlevel == 1 Goto C250
Goto Cont1

:C250
REM
REM In this case, the system must have returned 250 which means ok.
FIND "250" < %logfile% > %logfile2%
if errorlevel == 1 (
Echo.
Echo ====================================================================
Echo Error occured!
Echo --------------
Echo Test for lib %lib% did not execute correctly.
Echo ====================================================================
Echo.
Echo Check the log below:
Echo ------------------------[ Start of log ]----------------------------
Type %logfile%
Echo -------------------------[ End of log ]-----------------------------
Pause
Goto Exit
)
:Cont1

Echo open %ibminame% > %scriptfile%
Echo %user% >> %scriptfile%
Echo %pwd% >> %scriptfile%
Echo quote rcmd dspfd %lib%/*all type(*basatr) output(*outfile) outfile(qtemp/dspfd) >> %scriptfile%
Echo get /QSYS.LIB/QTEMP.LIB/DSPFD.FILE .\%lib%.DspFD >> %scriptfile%
Echo quote rcmd dltf qtemp/dspfd >> %scriptfile%
Echo Quit >> %scriptfile%
REM
REM Execute FTP
REM
FTP -s:%scriptfile% > %logfile% 2>&1
REM
REM Check that we are connected to an iSeries.
REM
FIND "550-" < %logfile% > %logfile2%
If errorlevel == 1 Goto C2501
Goto Cont2

:C2501
REM
REM In this case, the system must have returned 250 which means ok.
FIND "250" < %logfile% > %logfile2%
if errorlevel == 1 (
Echo.
Echo ====================================================================
Echo Error occured!
Echo --------------
Echo Performing the command DSPFD on the library %lib% did not execute
Echo correctly.
Echo ====================================================================
Echo.
Echo Check the log below:
Echo ------------------------[ Start of log ]----------------------------
Type %logfile%
Echo -------------------------[ End of log ]-----------------------------
Pause
Goto Exit
)
:Cont2

REM
REM Get and filter the list of files.
REM

CScript.exe "%~dp0BackUpSrcDta.vbs" "%user%" "%pwd%" "%ibminame%" "%lib%" "%~dp0%lib%.DspFD"

Exit /b
REM
REM End of job
REM ----------
REM
:Exit
if exist %scriptfile%  del %scriptfile%
set scriptfile=
set logfile=
set logfile2=
set user=
set pwd=
set ibminame=
